

% --------------------------------------------------------
% Equations for BPOP model ver.1
%       Elisa Lovecchio 2019 (e.lovecchio@exeter.ac.uk)
% --------------------------------------------------------


function dxdy = eqn_BPOP_LOOPzrem(t,var)

param_BPOP_LOOPzrem

% get vars

P_ss = var(1); P_ds = var(2); P_so = var(3); P_do = var(4);
P_shSed = var(5); P_ooSed = var(6);

O_ss = var(7); O_ds = var(8); O_so = var(9); O_do = var(10); 
O2frac_atmo = var(11); 

ij_idx = var(12); % passing parameter

%P_check = var(13); % mass conservation check (variable not used in equations)
%O_check = var(14); % mass conservation check (variable not used in equations)

ispositive=(O2frac_atmo>0);

% --------------------------------------
%     Bio pump details

[ilarge,ismall] =  ind2sub([Nil,Nis],ij_idx);

zrem_small = zrem_small_min+(ismall-1)*dsmall;
zrem_large = zrem_large_min+(ilarge-1)*dlarge;
    
coag_rate_eff = coag_rate;



% --------------------------------------
% 1. surface shelf (ss)

P_riv_sh =  P_riv_in/V_ss*(1-P_frac_so);

P_adv_mix_ss = (Upw*(P_ds-P_ss)+SS_mix*(P_so-P_ss)+VS_mix*(P_ds-P_ss))/V_ss;

prod_ss = P_up_eff * (P_ss/(P_ss+Ks_P)) * P_ss; 

coag_ss = (prod_ss) * coag_rate_eff; 
smallPOPflx_ss = (prod_ss - coag_ss) * DeltaZ_eu; % particle flux at middle box [mmolP m-2 yr-1] 
largePOPflx_ss = coag_ss * DeltaZ_eu; 

exp_shelf_small = smallPOPflx_ss * exp(-(DeltaZ_eu/2)/zrem_small);  % particle flux at box boundary [mmolP m-2 yr-1] 
exp_shelf_large = largePOPflx_ss * exp(-(DeltaZ_eu/2)/zrem_large); 
exp_shelf = exp_shelf_large + exp_shelf_small; % [mmolP m-2 yr-1]
exp_shelf_byVol = exp_shelf / DeltaZ_eu; % removed concentration of P over the box [mmolP m-3 yr-1]

dP_ss = P_riv_sh + P_adv_mix_ss - exp_shelf_byVol; 

% --

O_adv_mix_ss = (Upw*(O_ds-O_ss)+SS_mix*(O_so-O_ss)+VS_mix*(O_ds-O_ss))/V_ss;

O_prod_ss = OP_redf * exp_shelf_byVol; 

O_airsea_ss_mmolyr = K_w_myr * (O2frac_atmo/K_Henri - O_ss) * Area_shelf; 
O_airsea_ss = O_airsea_ss_mmolyr / V_ss;

dO_ss = O_adv_mix_ss + O_prod_ss + O_airsea_ss; 


% --------------------------------------
% 2. deep shelf (ds)

P_adv_mix_ds = (Upw*(P_do-P_ds)+DS_mix*(P_do-P_ds)+VS_mix*(P_ss-P_ds))/V_ds; 

new_smallPOPflx_ds = exp_shelf_small; % [mmolP m-2 yr-1]
new_largePOPflx_ds = exp_shelf_large;

f_burial_small_ds = exp(-DeltaZ_ds/zrem_small);
f_burial_large_ds = exp(-DeltaZ_ds/zrem_large);
remin_shelf_small = new_smallPOPflx_ds * (1-f_burial_small_ds); % [mmolP m-2 yr-1]
remin_shelf_large = new_largePOPflx_ds * (1-f_burial_large_ds); 
remin_shelf = remin_shelf_small + remin_shelf_large;
remin_shelf_byVol = remin_shelf / DeltaZ_ds; % released P over the volume of the box

MM_O2_sed_ds = O_ds / (O_ds+K_O2_sed); 
oxic_remin_sedim_shelf = max_remin_rate * MM_O2_sed_ds * P_shSed/DeltaZ_ds;
anox_remin_sedim_shelf = max_remin_rate * anox_boost * (1 - MM_O2_sed_ds) * P_shSed/DeltaZ_ds;
remin_sedim_shelf = oxic_remin_sedim_shelf + anox_remin_sedim_shelf;

dP_ds = P_adv_mix_ds + remin_shelf_byVol + remin_sedim_shelf; 

% --

O_adv_mix_ds = (Upw*(O_do-O_ds)+DS_mix*(O_do-O_ds)+VS_mix*(O_ss-O_ds))/V_ds;

MM_O2_wc_ds = O_ds / (O_ds+K_O2_wc);
Osink_remin_ds = MM_O2_wc_ds * (remin_shelf_byVol * OP_redf); 
Anaer_remin_ds = (1-MM_O2_wc_ds) * (remin_shelf_byVol * OP_redf); 

Osink_sedim_ds = oxic_remin_sedim_shelf * OP_redf;
Anaer_sedim_ds = anox_remin_sedim_shelf * OP_redf; 

dO_ds = O_adv_mix_ds - Osink_remin_ds - Osink_sedim_ds; 




% --------------------------------------
% 3. surface open ocean (so)

P_riv_so =  P_riv_in/V_so*P_frac_so;

P_adv_mix_so = (Upw*(P_ss-P_so)+SS_mix*(P_ss-P_so)+Mix*(P_do-P_so))/V_so;

prod_so = P_up_eff * (P_so/(P_so+Ks_P)) * P_so;
coag_so = (prod_so) * coag_rate_eff; 
smallPOPflx_so = (prod_so - coag_so) * DeltaZ_eu; % particle flux at middle box [mmolP m-2 yr-1]
largePOPflx_so = coag_so * DeltaZ_eu; 
exp_so_small = smallPOPflx_so * exp(-(DeltaZ_eu/2)/zrem_small); 
exp_so_large = largePOPflx_so * exp(-(DeltaZ_eu/2)/zrem_large); 
exp_so = exp_so_large + exp_so_small;
exp_so_byVol = exp_so / DeltaZ_eu; % removed concentration of P over the box volume [mmolP m-3 yr-1]

dP_so = P_riv_so + P_adv_mix_so - exp_so_byVol; 

% --

O_adv_mix_so = (Upw*(O_ss-O_so)+SS_mix*(O_ss-O_so)+Mix*(O_do-O_so))/V_so;

O_prod_so = OP_redf * exp_so_byVol; 

O_airsea_so_mmolyr = K_w_myr * (O2frac_atmo/K_Henri - O_so) * Area_openo; 
O_airsea_so = O_airsea_so_mmolyr / V_so;

dO_so = O_adv_mix_so + O_prod_so + O_airsea_so; 


% --------------------------------------
% 4. deep open ocean (do)

P_adv_mix_do = (Upw*(P_so-P_do)+Mix*(P_so-P_do)+DS_mix*(P_ds-P_do))/V_do;
  
new_smallPOPflx_do = exp_so_small; % [mmolP m-2 yr-1]
new_largePOPflx_do = exp_so_large; 
f_burial_small_do = exp(-DeltaZ_do/zrem_small); 
f_burial_large_do = exp(-DeltaZ_do/zrem_large); 
remin_open_small = new_smallPOPflx_do * (1-f_burial_small_do); 
remin_open_large = new_largePOPflx_do * (1-f_burial_large_do); 
remin_open = remin_open_small + remin_open_large;
remin_open_byVol = remin_open / DeltaZ_do;  % released P over entire box volume [mmolP m-3 yr-1]

MM_O2_sed_do = O_do / (O_do+K_O2_sed); 
oxic_remin_sedim_open = max_remin_rate * MM_O2_sed_do * P_ooSed/DeltaZ_do;
anox_remin_sedim_open = max_remin_rate * anox_boost * (1 - MM_O2_sed_do) * P_ooSed/DeltaZ_do;
remin_sedim_open = oxic_remin_sedim_open + anox_remin_sedim_open;

dP_do = P_adv_mix_do + remin_open_byVol + remin_sedim_open; 

% --

O_adv_mix_do = (Upw*(O_so-O_do)+Mix*(O_so-O_do)+DS_mix*(O_ds-O_do))/V_do;

MM_O2_wc_do = O_do / (O_do+K_O2_wc); 
Osink_remin_do = MM_O2_wc_do * (remin_open_byVol * OP_redf); 
Anaer_remin_do = (1-MM_O2_wc_do) * (remin_open_byVol * OP_redf); 

Osink_sedim_do = oxic_remin_sedim_open * OP_redf;
Anaer_sedim_do = anox_remin_sedim_open * OP_redf; 

dO_do = O_adv_mix_do - Osink_remin_do - Osink_sedim_do; 


% --------------------------------------
% 5. atmosphere (atmo)
                      
O_airsea_ss_atmo = O_airsea_ss_mmolyr/mmol_atmo; 
O_airsea_so_atmo = O_airsea_so_mmolyr/mmol_atmo;

AnaerReact_WC = (Anaer_remin_ds*V_ds + Anaer_remin_do*V_do)/mmol_atmo;
AnaerReact_Sed = (Anaer_sedim_ds*V_ds + Anaer_sedim_do*V_do)/mmol_atmo;

OxyWeath = Wox0_mmol * sqrt(O2frac_atmo*ispositive/O2mix_now)/mmol_atmo;

dpO2_atmo = - O_airsea_ss_atmo - O_airsea_so_atmo - OxyWeath - AnaerReact_WC - AnaerReact_Sed; 



% --------------------------------------
% 6. Sediments (Organic P reservoir, slowly remineralized or buried)

sedim_accum_shelf_small = new_smallPOPflx_ds * f_burial_small_ds; % [mmolP m-2 yr-1]
sedim_accum_shelf_large = new_largePOPflx_ds * f_burial_large_ds;
sedim_accum_shelf = (sedim_accum_shelf_small + sedim_accum_shelf_large);

CaP_form_ds = P_shSed^2 * CaP_rate_mmol * (MM_O2_sed_ds + anox_slwdwn * (1 - MM_O2_sed_ds)); 

dP_shSed = sedim_accum_shelf - CaP_form_ds - remin_sedim_shelf*DeltaZ_ds; 

% ---

sedim_accum_open_small = new_smallPOPflx_do * f_burial_small_do; % [mmolP m-2 yr-1]
sedim_accum_open_large = new_largePOPflx_do * f_burial_large_do;
sedim_accum_open = (sedim_accum_open_small + sedim_accum_open_large);

CaP_form_do = P_ooSed^2 * CaP_rate_mmol * (MM_O2_sed_do + anox_slwdwn * (1 - MM_O2_sed_do)); 

dP_ooSed = sedim_accum_open - CaP_form_do - remin_sedim_open*DeltaZ_do; 


% =======================================

% Mass conservation checks on TOTAL BUDGETS

Ptot_netinput = P_riv_in - CaP_form_ds*Area_shelf - CaP_form_do*Area_openo;

O_source = O_prod_ss*V_ss + O_prod_so*V_so;
O_sink = (Osink_remin_ds+Osink_sedim_ds)*V_ds + (Osink_remin_do+Osink_sedim_do)*V_do +...
    (AnaerReact_WC+AnaerReact_Sed)*mmol_atmo + OxyWeath*mmol_atmo;
Otot_netinput = O_source - O_sink;

dPtot_check = Ptot_netinput/1e12*1e-3; % [Tmol P]
dOtot_check = Otot_netinput/1e15*1e-3; % [Pmol O_2]

% =======================================

dxdy=[dP_ss; dP_ds; dP_so; dP_do; dP_shSed; dP_ooSed; ...
           dO_ss; dO_ds; dO_so; dO_do; dpO2_atmo; 0; dPtot_check; dOtot_check];

end



