
% --------------------------------------------------------
% Parameters for BPOP model ver.1
%       Elisa Lovecchio 2019 (e.lovecchio@exeter.ac.uk)
% --------------------------------------------------------

% Model parameters


% ===== Simulation details: folders and flags

runtitle='00_Baseline';

output_dir='...';

% ===== Biopump details

% remin lengths
zrem_small_min = 0; % m    %zrem_small_max = 40; % m
zrem_large_min = 50; % m   %zrem_large_max = 455; % m

dsmall= 2;
dlarge= 20;
Nis = 21; % how many values of zremS do you want to explore
Nil = 21; % how many values of zremL do you want to explore

coag_rate = 0.22; % fraction of production that coagulates

max_remin_rate = 0.001 * 365.25; % 1/yr

% NB: to go back to a 1 sinking Porg type only (it uses the "small" type) set the params as follows: 
%     zrem_small = your choice; zrem_large = #unused;
%     coag_rate = 0;


% ===== Box properties

DeltaZ_eu = 100;  % m (depth of the surface ocean -  euph layer)
DeltaZ_ds = 100;  % m (depth of the deep shelf)
DeltaZ_do = 3500; % m (depth of the deep open ocean)

Ocean_area = 361 *1e12; % m^2 (saline waters cover about 361000000 km^2 = 361 * 1e6 km^2 = 361 * 1e12 m^2)
Shelf_perc = 7; % today shelf seas up to 200 m cover about 7% of the ocean surf (Barron and Duarte, 2015; Wollast, 1998)

Area_shelf = Ocean_area*(Shelf_perc/100); % m^2
Area_openo = Ocean_area*((100-Shelf_perc)/100);% m^2

% - Box volumes 
V_ss = DeltaZ_eu*Area_shelf; % m^3 
V_ds = DeltaZ_ds*Area_shelf; % m^3 
V_so = DeltaZ_eu*Area_openo; % m^3 
V_do = DeltaZ_do*Area_openo; % m^3 

Vol_vec=[V_ss; V_ds; V_so; V_do];

Mol_atmo = 1.8 * 10^20; % Moles in atmospheric box [mol]
mmol_atmo = Mol_atmo * 10^3; % millimoles in atmospheric box [mmol]

t_simu = 70*1e6; % total simulation time in years 
spy = 3600 * 24.0 * 365.25; % seconds per year


% ===== Initial values

PO4_ini = 2.2; % muM = mu_mol/L = mmol/m^3

O2_ini = 0.0; % muM = mu_mol/L = mmol/m^3 (assuming ocean is not oxygenated at the beginning)


% ===== Mixing/advection between boxes [in units of m^3 per year (or dt)]

Mix = 40 * 1e6 * spy; % 40 Sv (mixing in open ocean high lats)
Upw = 6 * 1e6 * spy;  % NB: 5.5 Sv only in the 4 main EBUS (upwelling cell circulation between shelf and low lats)
     
SS_mix = 0.5 * 1e6 * spy; % 1 Sv (surf shelf lateral mixing)  
DS_mix = 0.5 * 1e6 * spy; %  1 Sv (deep shelf lateral mixing)

VS_mix = 1 * 1e6 * spy; %  1 Sv (vertical mixing in shelf)

LatFlx_ss = (Upw+SS_mix);
LatFlx_ds = DS_mix;

% ===== River input flux  

P_riv = 0.092; % Tmol/yr = 10^12 mol/yr 
P_riv_in = P_riv * 1e12 * 1000; % mmol/yr

P_frac_so = 0.4; % fraction of P delivered to open waters 


% ===== Bio parameters and input flux

P_up_eff = 0.8; % 1/yr % P uptake rate  
Ks_P = 0.2; % mmol/m^3 Michaelis menten half-sat constant for P uptake

OP_redf = 150; % O to P ratio in marine organic matter 
K_O2_sed = 0.2; % muM = mmol/m^3 Michaelis menten half-sat constant for O uptake in sediments
K_O2_wc = 15.0; % mmol/m^3 Michaelis menten half-sat constant for O uptake in water column
anox_boost = 1.25; % Porg remineralization increase under anoxia (+25%) 

% ===== Gas transfer params (O2)

% NB: all the following is from Sarmiento Gruber 2006
T_mean = 17.64; % degC (global mean temperature)
W_speed = 7.5; % m/s (global mean wind speed)         % below: Keeling et al 1998

N_sch = 1638 - 81.83*T_mean +1.483*T_mean^2 - 0.008004*T_mean^3; % Schmidt number for a salinity of 35

K_w = 0.31 * W_speed^2 * (660/N_sch)^0.5; % cm/h, Gas transfer velocity Wanninkof 1992 
K_w_myr = K_w * 10^(-2) * (24*365.25); % m/yr 

K_Henri = 770.0 * 10^(-6); % L*atm/mol --> m^3*atm/mmol (converts partial pressure to dissolved concentration)


% ===== Oxy Weathering params

O2mix_now = 0.21; % current O mixing ratio in atmosphere
Wox0_mmol = (P_riv * 1e12 * 1000) * OP_redf; % baseline oxidative weathering flux


% ===== CaP formation rate

CaP_rate_mmol = 0.5; % 1/yr*(mmol/m^2)^(-1) Ca-P formation rate
anox_slwdwn = 0.5; % CaP formation inhibition under anoxia (-50%)   

