
% --------------------------------------------------------
% Run call for BPOP model ver.1 
%       Elisa Lovecchio 2019 (e.lovecchio@exeter.ac.uk)
% --------------------------------------------------------


clc
close all


param_BPOP_LOOPzrem % <--- loads PARAMETER SET



% --- set here plotting flag for current script ---

plotting_flag=false; % set to true to plot the evolution of the variables for each run (each couple of zrem values)
                     % NB: slows down the program quite a bit

                     

%% Initialization of the output variables  

final_vars = zeros(13,Nis*Nil);  
final_flxs = zeros(14,Nis*Nil);
final_flxsByP = zeros(18,Nis*Nil);

var_names = {'z_{rem} SMALL [m]','z_{rem} LARGE [m]',...
    'P_{ss} [mmol/m^3]','P_{ds} [mmol/m^3]','P_{so} [mmol/m^3]','P_{do} [mmol/m^3]',...
    'Porg_{seds} [mmol/m^2]','Porg_{sedo} [mmol/m^2]',...
    'O_{ss} [mmol/m^3]','O_{ds} [mmol/m^3]','O_{so} [mmol/m^3]','O_{do} [mmol/m^3]',...
    'O_{atmo} [mmol/m^3]'};

flx_names = {'z_{rem} SMALL [m]','z_{rem} LARGE [m]',...
    'Prod_{shelf} [TmolP/yr]','Prod_{open} [TmolP/yr]','Exp_{shelf} [TmolP/yr]','Exp_{open} [TmolP/yr]',...
    'SedAcc_{shelf} [TmolP/yr]','SedAcc_{open} [TmolP/yr]','Bur_{shelf} [mmol/m^3]','Bur_{open} [mmol/m^3]',...
    'RemWat_{shelf} [TmolP/yr]','RemWat_{open} [TmolP/yr]','RemSed_{shelf} [mmol/m^3]','RemSed_{open} [mmol/m^3]'};
  
flxbyP_names = {'z_{rem} SMALL [m]','z_{rem} LARGE [m]',...
    'ProdSmall_{shelf} [TmolP/yr]','ProdLarge_{shelf} [TmolP/yr]','ProdSmall_{open} [TmolP/yr]','ProdLarge_{open} [TmolP/yr]',...
    'ExpSmall_{shelf} [TmolP/yr]','ExpLarge_{shelf} [TmolP/yr]','ExpSmall_{open} [TmolP/yr]','ExpLarge_{open} [TmolP/yr]',...
    'PdepthSmall_{shelf} [TmolP/yr]','PdepthLarge_{shelf} [TmolP/yr]','PdepthSmall_{open} [TmolP/yr]','PdepthLarge_{open} [TmolP/yr]',...
    'SedAccSmall_{shelf} [TmolP/yr]','SedAccLarge_{shelf} [TmolP/yr]','SedAccSmall_{open} [TmolP/yr]','SedAccLarge_{open} [TmolP/yr]'};
 
  

%% runs cycle


for ismall=1:Nis
    for ilarge=1:Nil
    
    % calculate zrem for current indeces
    
    zrem_small = zrem_small_min+(ismall-1)*dsmall;
    zrem_large = zrem_large_min+(ilarge-1)*dlarge;
    
    coag_rate_eff = coag_rate; 
    
    ij_idx=sub2ind([Nil,Nis],ilarge,ismall);
    
    
    
    final_vars(1,ij_idx)=zrem_small;
    final_vars(2,ij_idx)=zrem_large;
    final_flxs(1,ij_idx)=zrem_small;
    final_flxs(2,ij_idx)=zrem_large;
    final_flxsByP(1,ij_idx)=zrem_small;
    final_flxsByP(2,ij_idx)=zrem_large;
   
    
    % ======================
    % display run properties

    disp('==============================================================')
    disp(['Running: ',runtitle])
    disp(['--> z_rem^S = ',num2str(zrem_small),' m; z_rem^L = ',num2str(zrem_large),' m']);
    
    
    % Build name to save plots
    param_set=['zremS',num2str(zrem_small),'m_zremL',num2str(zrem_large),'m'];
    iruntitle=[runtitle,'-',param_set];
    
    
    % =================================
    % Initialization of state variables
    P_ss_ini = PO4_ini; % surface shelf
    P_ds_ini = PO4_ini; % deep shelf
    P_so_ini = PO4_ini; % surface open ocean
    P_do_ini = PO4_ini; % deep open ocean
    
    P_shSed_ini = 0; % shelf sediments
    P_ooSed_ini = 0; % open ocean sediments
    
    O_ss_ini = O2_ini; % surface shelf
    O_ds_ini = O2_ini; % deep shelf
    O_so_ini = O2_ini; % surface open ocean
    O_do_ini = O2_ini; % deep open ocean
    
    O2frac_atmo_ini = O2_ini; % atmosphere
    ij=ij_idx;
    
    Ptot_masscheck_ini=(P_ss_ini*V_ss + P_ds_ini*V_ds + P_so_ini*V_so + P_do_ini*V_do +...
        P_shSed_ini*Area_shelf + P_ooSed_ini*Area_openo)/1e12*1e-3; % P tot
    Otot_masscheck_ini=(O_ss_ini*V_ss + O_ds_ini*V_ds + O_so_ini*V_so + O_do_ini*V_do +...
        O2frac_atmo_ini*mmol_atmo)/1e15*1e-3; % O_2 tot
    
    % define input vectors
    tspan=[0,t_simu];
    y0=[P_ss_ini,P_ds_ini,P_so_ini,P_do_ini,P_shSed_ini,P_ooSed_ini,...
        O_ss_ini,O_ds_ini,O_so_ini,O_do_ini,O2frac_atmo_ini,ij,...
        Ptot_masscheck_ini,Otot_masscheck_ini];
    
    
    % =================
    % INTEGRATION
    
    tic;
    
    % integrate
    [t,y]=ode15s(@(t,y) eqn_BPOP_LOOPzrem(t,y),tspan,y0);
    
    toc;
    disp(['TIMER: The simulation took ', num2str(toc/60),' min to integrate ',num2str(t_simu/1e6),' Myr.'])
    
    
    % end integration
    % =================
    

    
    % ================
    % output variables
    
    P_ss=y(:,1); % surface shelf
    P_ds=y(:,2); % deep shelf
    P_so=y(:,3); % surface open ocean
    P_do=y(:,4); % deep open ocean
    
    P_shSed=y(:,5); % shelf sediments
    P_ooSed=y(:,6); % open ocean sediments
    
    O_ss=y(:,7); % surface shelf
    O_ds=y(:,8); % deep shelf
    O_so=y(:,9); % surface open ocean
    O_do=y(:,10); % deep open ocean
    
    O2frac_atmo=y(:,11); % atmosphere

    Ptot_masscheck = y(:,13); % diagnostic: P tot
    Otot_masscheck = y(:,14); % diagnostic: O_2 tot
    
    
    
    % =====================================================================
    %  plotting
    
    if plotting_flag
    
    Tvec=t/1e6;
    lw=2;
    lwS=1;
    dplot = 1; % determines whether to plot all tsteps(=1) or every dplot timesteps (faster)
    
    title_string=['Param: ',param_set];
    
    hf=figure(1);
    clf
    set(hf,'PaperUnits','inches','PaperPosition',[0, 0, 5, 5])
    
    title(title_string,'FontSize',10)
    
    subplot(2,2,1)
    hold on
    title('P(t) [mmol/m^3]')
    yyaxis left
    plot(Tvec(1:dplot:end),P_ss(1:dplot:end),'-','LineWidth',lw,'Color',[0.2 0.8 1])
    plot(Tvec(1:dplot:end),P_ds(1:dplot:end),'-','LineWidth',lw,'Color',[0.2 0.2 1])
    plot(Tvec(1:dplot:end),P_so(1:dplot:end),'-','LineWidth',lw,'Color',[1 0.7 0.2])
    plot(Tvec(1:dplot:end),P_do(1:dplot:end),'-','LineWidth',lw,'Color',[1 0.2 0.2])
    ylim([0,max(max(y(:,1:4)))])
    ylabel('conc [mmol/m^3]','FontSize',10)
    yyaxis right
    plot(Tvec(1:dplot:end),P_shSed(1:dplot:end),':','LineWidth',lwS,'Color',[0.2 0.2 1])
    plot(Tvec(1:dplot:end),P_ooSed(1:dplot:end),':','LineWidth',lwS,'Color',[1 0.2 0.2])
    ylabel('conc [mmol/m^2]','FontSize',10)
    legend('surf shelf','deep shelf','surf open','deep open','shelf SED','open SED')
    xlim([0,max(Tvec)])
    xlabel('time [Myr]','FontSize',10)
    hold off
    
    subplot(2,2,2)
    hold on
    title('O(t) [mmol/m^3]')
    yyaxis left
    plot(Tvec(1:dplot:end),O_ss(1:dplot:end),'-','LineWidth',lw,'Color',[0.2 0.8 1])
    plot(Tvec(1:dplot:end),O_ds(1:dplot:end),'-','LineWidth',lw,'Color',[0.2 0.2 1])
    plot(Tvec(1:dplot:end),O_so(1:dplot:end),'-','LineWidth',lw,'Color',[1 0.7 0.2])
    plot(Tvec(1:dplot:end),O_do(1:dplot:end),'-','LineWidth',lw,'Color',[1 0.2 0.2])
    ylim([0,max(max(y(:,7:10)))])
    ylabel('conc [mmol/m^3]','FontSize',10)
    yyaxis right
    plot(Tvec(1:dplot:end),O2frac_atmo(1:dplot:end)*100,'--k','LineWidth',lw)
    legend('surf shelf','deep shelf','surf open','deep open','atmo','Location','northwest')
    ylim([0,max(1,max(O2frac_atmo(1:dplot:end))*100)])
    ylabel('% atmo','FontSize',10)
    xlim([0,max(Tvec)])
    xlabel('time [Myr]','FontSize',10)
    hold off
    
    Ptot = P_ss(1:dplot:end)*V_ss+P_ds(1:dplot:end)*V_ds+P_so(1:dplot:end)*V_so+P_do(1:dplot:end)*V_do+...
        P_shSed*Area_shelf + P_ooSed*Area_openo;
    Otot=O_ss*V_ss + O_ds*V_ds + O_so*V_so + O_do*V_do + O2frac_atmo*mmol_atmo;
    
    subplot(2,2,3)
    hold on
    title('P budget (t) [TmolP]')
    yyaxis left
    plot(Tvec(1:dplot:end),Ptot/1e12*1e-3,'-','LineWidth',lw+3,'Color','r')
    plot(Tvec(1:dplot:end),Ptot_masscheck,'-','LineWidth',lw,'Color','k')
    ylabel('P [TmolP]','FontSize',10)
    legend('Tot P boxes','P^{TOT}')
    xlim([0,max(Tvec)])
    xlabel('time [Myr]','FontSize',10)
    hold off
    
    subplot(2,2,4)
    hold on
    title('O budget (t) [PmolO_2]')
    yyaxis left
    plot(Tvec(1:dplot:end),Otot/1e15*1e-3,'-','LineWidth',lw+3,'Color','r')
    plot(Tvec(1:dplot:end),Otot_masscheck,'-','LineWidth',lw,'Color','k')
    %ylim([0,max(max(y(:,7:10)))])
    ylabel('Otot [PmolO_2]','FontSize',10)
    legend('Tot O boxes','O^{TOT}', 'Location','southeast')
    xlim([0,max(Tvec)])
    xlabel('time [Myr]','FontSize',10)
    hold off
    
    print(hf,[output_dir,iruntitle],'-dpng','-r300');
    
    end
    
    
    % ====================================================================
    % Final values (last time step)

    final_vars(3,ij_idx)=P_ss(end);
    final_vars(4,ij_idx)=P_ds(end);
    final_vars(5,ij_idx)=P_so(end);
    final_vars(6,ij_idx)=P_do(end);
    
    final_vars(7,ij_idx)=P_shSed(end);
    final_vars(8,ij_idx)=P_ooSed(end);
    
    final_vars(9,ij_idx)=O_ss(end);
    final_vars(10,ij_idx)=O_ds(end);
    final_vars(11,ij_idx)=O_so(end);
    final_vars(12,ij_idx)=O_do(end);
    
    final_vars(13,ij_idx)=O2frac_atmo(end);   
    

    % ====================================================================
    % Fluxes calculation for final values
    % NB: these calculations must correspond to those in the equations file
    
    % -------
    % SURFACE
    
    prod_ss = P_up_eff * P_ss(end) * (P_ss(end)/(P_ss(end)+Ks_P)); 
    prod_so = P_up_eff * P_so(end) * (P_so(end)/(P_so(end)+Ks_P)); 
    
    prod_tot = prod_ss * V_ss + prod_so * V_so;
    final_flxs(3,ij_idx)=prod_ss * V_ss/1e12*1e-3;
    final_flxs(4,ij_idx)=prod_so * V_so/1e12*1e-3;
    
    coag_ss = prod_ss * coag_rate_eff; 
    small_POP_ss = prod_ss - coag_ss; % concentration of P over the box [mmolP m-3 yr-1]
    large_POP_ss = coag_ss;
    smallPOPflx_ss = small_POP_ss * DeltaZ_eu; % particle flux at middle of box [mmolP m-2 yr-1]
    largePOPflx_ss = large_POP_ss * DeltaZ_eu;
    exp_shelf_small = smallPOPflx_ss * exp(-(DeltaZ_eu/2)/zrem_small);  % particle flux at box bottom [mmolP m-2 yr-1]
    exp_shelf_large = largePOPflx_ss * exp(-(DeltaZ_eu/2)/zrem_large);
    exp_shelf = exp_shelf_large + exp_shelf_small; % [mmolP m-2 yr-1]
    
    coag_so = prod_so * coag_rate_eff;
    small_POP_so = prod_so - coag_so;
    large_POP_so = coag_so;
    smallPOPflx_so = small_POP_so * DeltaZ_eu; % particle flux at middle box [mmolP m-2 yr-1]
    largePOPflx_so = large_POP_so * DeltaZ_eu;
    exp_so_small = smallPOPflx_so * exp(-(DeltaZ_eu/2)/zrem_small); % particle flux at box bottom [mmolP m-2 yr-1]
    exp_so_large = largePOPflx_so * exp(-(DeltaZ_eu/2)/zrem_large);
    exp_so = exp_so_large + exp_so_small;
    
    
    % Fluxes by volume
    
    exp_shelf_byVol = exp_shelf / DeltaZ_eu; % removed concentration of P over the box [mmolP m-3 yr-1]
    exp_shelf_small_byVol = exp_shelf_small / DeltaZ_eu;
    exp_shelf_large_byVol = exp_shelf_large / DeltaZ_eu;
    
    exp_so_byVol = exp_so / DeltaZ_eu; % removed concentration of P over the box [mmolP m-3 yr-1]
    exp_so_small_byVol = exp_so_small / DeltaZ_eu;
    exp_so_large_byVol = exp_so_large / DeltaZ_eu;
    
    final_flxs(5,ij_idx)=exp_shelf_byVol * V_ss/1e12*1e-3;
    final_flxs(6,ij_idx)=exp_so_byVol * V_so/1e12*1e-3;
    
    final_flxsByP(3,ij_idx)=small_POP_ss;
    final_flxsByP(4,ij_idx)=large_POP_ss;
    final_flxsByP(5,ij_idx)=small_POP_so;
    final_flxsByP(6,ij_idx)=large_POP_so;
    
    final_flxsByP(7,ij_idx)=exp_shelf_small_byVol;
    final_flxsByP(8,ij_idx)=exp_shelf_large_byVol;
    final_flxsByP(9,ij_idx)=exp_so_small_byVol;
    final_flxsByP(10,ij_idx)=exp_so_large_byVol;
    
    
    % -----
    % DEPTH
    
    new_smallPOPflx_ds = exp_shelf_small; % particle flux at box top [mmolP m-2 yr-1]
    new_largePOPflx_ds = exp_shelf_large;
    f_burial_small_ds = exp(-DeltaZ_ds/zrem_small);
    f_burial_large_ds = exp(-DeltaZ_ds/zrem_large);
    remin_shelf_small = new_smallPOPflx_ds * (1-f_burial_small_ds); % [mmolP m-2 yr-1]
    remin_shelf_large = new_largePOPflx_ds * (1-f_burial_large_ds);
    remin_shelf = remin_shelf_small + remin_shelf_large;
    remin_shelf_byVol = remin_shelf / DeltaZ_ds; % released P over the volume of the box

    MM_O2_sed_ds = O_ds(end) / (O_ds(end)+K_O2_sed); 
    oxic_remin_sedim_shelf = max_remin_rate * MM_O2_sed_ds * P_shSed(end)/DeltaZ_ds;
    anox_remin_sedim_shelf = max_remin_rate * anox_boost * (1 - MM_O2_sed_ds) * P_shSed(end)/DeltaZ_ds;
    remin_sedim_shelf = oxic_remin_sedim_shelf + anox_remin_sedim_shelf;
    
    new_smallPOPflx_do = exp_so_small; % particle flux at box top [mmolP m-2 yr-1]
    new_largePOPflx_do = exp_so_large;
    f_burial_small_do = exp(-DeltaZ_do/zrem_small);
    f_burial_large_do = exp(-DeltaZ_do/zrem_large);
    remin_open_small = new_smallPOPflx_do * (1-f_burial_small_do);
    remin_open_large = new_largePOPflx_do * (1-f_burial_large_do);
    remin_open = remin_open_small + remin_open_large;
    remin_open_byVol = remin_open / DeltaZ_do;  % released P over entire box volume [mmolP m-3 yr-1]

    MM_O2_sed_do = O_do(end) / (O_do(end)+K_O2_sed); 
    oxic_remin_sedim_open = max_remin_rate * MM_O2_sed_do * P_ooSed(end)/DeltaZ_do;
    anox_remin_sedim_open = max_remin_rate * anox_boost * (1 - MM_O2_sed_do) * P_ooSed(end)/DeltaZ_do;
    remin_sedim_open = oxic_remin_sedim_open + anox_remin_sedim_open;

    % Fluxes by Vol
    
    new_smallpart_ds = new_smallPOPflx_ds/DeltaZ_ds; % [mmolP m-3 yr-1]
    new_largepart_ds = new_largePOPflx_ds/DeltaZ_ds;
    new_smallpart_do = new_smallPOPflx_do/DeltaZ_do;
    new_largepart_do = new_largePOPflx_do/DeltaZ_do;
    
    final_flxsByP(11,ij_idx)=new_smallpart_ds;
    final_flxsByP(12,ij_idx)=new_largepart_ds;
    final_flxsByP(13,ij_idx)=new_smallpart_do;
    final_flxsByP(14,ij_idx)=new_largepart_do;
    
    % ---------
    % SEDIMENTS
    
    sedim_accum_shelf_small = new_smallPOPflx_ds * f_burial_small_ds; % [mmolP m-2 yr-1]
    sedim_accum_shelf_large = new_largePOPflx_ds * f_burial_large_ds;
    sedim_accum_shelf = sedim_accum_shelf_small + sedim_accum_shelf_large;
    
    CaP_form_ds = P_shSed(end)^2 * CaP_rate_mmol * (MM_O2_sed_ds + anox_slwdwn * (1 - MM_O2_sed_ds));
    CaP_shelf = CaP_form_ds;
    
    sedim_accum_open_small = new_smallPOPflx_do * f_burial_small_do; % [mmolP m-2 yr-1]
    sedim_accum_open_large = new_largePOPflx_do * f_burial_large_do;
    sedim_accum_open = sedim_accum_open_small + sedim_accum_open_large;
    
    CaP_form_do = P_ooSed(end) ^2 * CaP_rate_mmol * (MM_O2_sed_do + anox_slwdwn * (1 - MM_O2_sed_do));
    CaP_open = CaP_form_do;
    
    actual_burial = CaP_shelf * Area_shelf + CaP_open * Area_openo;
    
    
    sedim_accum = sedim_accum_shelf * Area_shelf + sedim_accum_open * Area_openo;
    sedim_accum_perA = (sedim_accum_shelf * Area_shelf + sedim_accum_open * Area_openo)/(Area_shelf + Area_openo);
    
    final_flxs(7,ij_idx)= sedim_accum_shelf * Area_shelf/1e12*1e-3; 
    final_flxs(8,ij_idx)= sedim_accum_open * Area_openo/1e12*1e-3;
    final_flxs(9,ij_idx)= CaP_shelf * Area_shelf/1e12*1e-3; 
    final_flxs(10,ij_idx)= CaP_open * Area_openo/1e12*1e-3;
    
    final_flxsByP(15,ij_idx)=sedim_accum_shelf_small;
    final_flxsByP(16,ij_idx)=sedim_accum_shelf_large;
    final_flxsByP(17,ij_idx)=sedim_accum_open_small;
    final_flxsByP(18,ij_idx)=sedim_accum_open_large;
    
    O_airsea_ss_mmolyrm2 = K_w_myr * (O2frac_atmo(end)/K_Henri - O_ss(end));
    O_airsea_so_mmolyrm2 = K_w_myr * (O2frac_atmo(end)/K_Henri - O_so(end));
    
    final_flxs(11,ij_idx) = remin_shelf_byVol * V_ds/1e12*1e-3;
    final_flxs(12,ij_idx) = remin_open_byVol * V_do/1e12*1e-3;
    final_flxs(13,ij_idx) = remin_sedim_shelf * V_ds/1e12*1e-3;
    final_flxs(14,ij_idx) = remin_sedim_open * V_do/1e12*1e-3;
    
    disp(' ')
    
    end
end

% ===============================
% Save final variables and fluxes

save([output_dir,runtitle,'_data'],'final_vars','var_names','final_flxs','flx_names','final_flxsByP','flxbyP_names');



diary off

















